@@ -7,7 +7,7 @@
 #ifndef __LIBXMLPP_ATTRIBUTEDECLARATION_H
 #define __LIBXMLPP_ATTRIBUTEDECLARATION_H
 
-#include <glibmm/ustring.h>
+#include "libxml++/ustring.h"
 
 #include <libxml++/attribute.h>
 
@@ -20,7 +20,7 @@ extern "C" {
 namespace xmlpp
 {
 
-/** Represents the default value of an attribute of an XML Element node.
+/** Represents the default value of an attribute of an XML element node.
  * This will be instantiated by the parser.
  *
  * @newin{2,36}
@@ -34,7 +34,7 @@ public:
   /** Get the default value of this attribute.
    * @returns The attribute's default value.
    */
-  Glib::ustring get_value() const override;
+  ustring get_value() const override;
 
   ///Access the underlying libxml implementation.
   _xmlAttribute* cobj() noexcept;
