@@ -12,25 +12,25 @@
 namespace xmlpp
 {
 
-/** Content Node. This will be instantiated by the parser.
+/** Content node. This will be instantiated by the parser.
  */
 class ContentNode : public Node
 {
 public:
   explicit ContentNode(_xmlNode* node);
-  virtual ~ContentNode();
+  ~ContentNode() override;
 
   /** Get the text of this content node.
    * @returns The text. Note that the 5 predefined entities (&amp;, &quot;, &lt;, &gt;, &apos;)
    * are always resolved, so this content will show their human-readable equivalents.
    */
-  Glib::ustring get_content() const;
+  ustring get_content() const;
 
   /** Set the text of this content node
    * @param content The text. This must be unescaped, meaning that the predefined entities will be created for you where necessary.
    * See get_content().
    */
-  void set_content(const Glib::ustring& content);
+  void set_content(const ustring& content);
 
   /// @returns Whether this node contains only white space, or is empty.
   bool is_white_space() const;
