@@ -27,7 +27,7 @@ class EntityDeclaration : public ContentNode
 {
 public:
   explicit EntityDeclaration(_xmlNode* node);
-  virtual ~EntityDeclaration();
+  ~EntityDeclaration() override;
 
   /** Get the text with character references (like "&#xdf;") resolved.
    * If the entity declaration does not contain any reference to another entity,
@@ -35,18 +35,18 @@ public:
    * document had been parsed with Parser::set_substitute_entities(true).
    * @returns The text with character references unescaped.
    */
-  Glib::ustring get_resolved_text() const;
+  ustring get_resolved_text() const;
 
   /** Get the text as read from the XML or DTD file.
    * @returns The escaped text.
    */
-  Glib::ustring get_original_text() const;
+  ustring get_original_text() const;
 
   ///Access the underlying libxml implementation.
-  _xmlEntity* cobj();
+  _xmlEntity* cobj() noexcept;
 
   ///Access the underlying libxml implementation.
-  const _xmlEntity* cobj() const;
+  const _xmlEntity* cobj() const noexcept;
 };
 
 } // namespace xmlpp
