@@ -4,59 +4,11 @@
  * included with libxml++ as the file COPYING.
  */
 
-// Direct access to xmlParserCtxt::options and xmlParserCtxt::linenumbers
-// is deprecated since libxml2 2.14.0.
-// xmlCtxtGetOptions() is new in libxml2 2.14.0.
-// Ignore deprecations here.
-#define XML_DEPRECATED_MEMBER
-
 #include "libxml++/exceptions/wrapped_exception.h"
 #include "libxml++/parsers/parser.h"
 
 #include <libxml/parser.h>
 
-namespace
-{
-// C++ linkage
-using ErrorOrWarningFuncType = void (*)(bool parser, bool error, void* ctx,
-                                        const char* msg, va_list var_args);
-ErrorOrWarningFuncType p_callback_error_or_warning;
-
-extern "C"
-{
-static void c_callback_parser_error(void* ctx, const char* msg, ...)
-{
-  va_list var_args;
-  va_start(var_args, msg);
-  p_callback_error_or_warning(true, true, ctx, msg, var_args);
-  va_end(var_args);
-}
-
-static void c_callback_parser_warning(void* ctx, const char* msg, ...)
-{
-  va_list var_args;
-  va_start(var_args, msg);
-  p_callback_error_or_warning(true, false, ctx, msg, var_args);
-  va_end(var_args);
-}
-static void c_callback_validity_error(void* ctx, const char* msg, ...)
-{
-  va_list var_args;
-  va_start(var_args, msg);
-  p_callback_error_or_warning(false, true, ctx, msg, var_args);
-  va_end(var_args);
-}
-
-static void c_callback_validity_warning(void* ctx, const char* msg, ...)
-{
-  va_list var_args;
-  va_start(var_args, msg);
-  p_callback_error_or_warning(false, false, ctx, msg, var_args);
-  va_end(var_args);
-}
-} // extern "C"
-} // anonymous namespace
-
 namespace xmlpp
 {
 
@@ -69,10 +21,10 @@ struct Parser::Impl
   {}
 
   // Built gradually - used in an exception at the end of parsing.
-  Glib::ustring parser_error_;
-  Glib::ustring parser_warning_;
-  Glib::ustring validate_error_;
-  Glib::ustring validate_warning_;
+  ustring parser_error_;
+  ustring parser_warning_;
+  ustring validate_error_;
+  ustring validate_warning_;
 
   bool throw_messages_;
   bool validate_;
@@ -184,17 +136,17 @@ void Parser::initialize_context()
   if (context_->sax && pimpl_->throw_messages_)
   {
     //Tell the parser context about the callbacks.
-    context_->sax->fatalError = get_callback_parser_error_cfunc();
-    context_->sax->error = get_callback_parser_error_cfunc();
-    context_->sax->warning = get_callback_parser_warning_cfunc();
+    context_->sax->fatalError = &callback_parser_error;
+    context_->sax->error = &callback_parser_error;
+    context_->sax->warning = &callback_parser_warning;
   }
 
   if (pimpl_->throw_messages_)
   {
     //Tell the validity context about the callbacks:
     //(These are only called if validation is on - see above)
-    context_->vctxt.error = get_callback_validity_error_cfunc();
-    context_->vctxt.warning = get_callback_validity_warning_cfunc();
+    context_->vctxt.error = &callback_validity_error;
+    context_->vctxt.warning = &callback_validity_warning;
   }
 
   //Allow callback_error_or_warning() to retrieve the C++ instance:
@@ -217,24 +169,24 @@ void Parser::release_underlying()
   }
 }
 
-void Parser::on_parser_error(const Glib::ustring& message)
+void Parser::on_parser_error(const ustring& message)
 {
   //Throw an exception later when the whole message has been received:
   pimpl_->parser_error_ += message;
 }
 
-void Parser::on_parser_warning(const Glib::ustring& message)
+void Parser::on_parser_warning(const ustring& message)
 {
   //Throw an exception later when the whole message has been received:
   pimpl_->parser_warning_ += message;
 }
-void Parser::on_validity_error(const Glib::ustring& message)
+void Parser::on_validity_error(const ustring& message)
 {
   //Throw an exception later when the whole message has been received:
   pimpl_->validate_error_ += message;
 }
 
-void Parser::on_validity_warning(const Glib::ustring& message)
+void Parser::on_validity_warning(const ustring& message)
 {
   //Throw an exception later when the whole message has been received:
   pimpl_->validate_warning_ += message;
@@ -242,7 +194,7 @@ void Parser::on_validity_warning(const Glib::ustring& message)
 
 void Parser::check_for_error_and_warning_messages()
 {
-  Glib::ustring msg(exception_ ? exception_->what() : "");
+  ustring msg(exception_ ? exception_->what() : "");
   bool parser_msg = false;
   bool validity_msg = false;
 
@@ -280,7 +232,6 @@ void Parser::check_for_error_and_warning_messages()
     exception_.reset(new parse_error(msg));
 }
 
-#ifndef LIBXMLXX_DISABLE_DEPRECATED
 //static
 void Parser::callback_parser_error(void* ctx, const char* msg, ...)
 {
@@ -320,44 +271,6 @@ void Parser::callback_validity_warning(void* ctx, const char* msg, ...)
 //static
 void Parser::callback_error_or_warning(MsgType msg_type, void* ctx,
                                        const char* msg, va_list var_args)
-{
-  const bool is_parser = (msg_type == MsgType::ParserError) || (msg_type == MsgType::ParserWarning);
-  const bool is_error = (msg_type == MsgType::ParserError) || (msg_type == MsgType::ValidityError);
-  callback_error_or_warning(is_parser, is_error, ctx, msg, var_args);
-}
-#endif // LIBXMLXX_DISABLE_DEPRECATED
-
-//static
-ParserCallbackCFuncType Parser::get_callback_parser_error_cfunc()
-{
-  p_callback_error_or_warning = &callback_error_or_warning;
-  return &c_callback_parser_error;
-}
-
-//static
-ParserCallbackCFuncType Parser::get_callback_parser_warning_cfunc()
-{
-  p_callback_error_or_warning = &callback_error_or_warning;
-  return &c_callback_parser_warning;
-}
-
-//static
-ParserCallbackCFuncType Parser::get_callback_validity_error_cfunc()
-{
-  p_callback_error_or_warning = &callback_error_or_warning;
-  return &c_callback_validity_error;
-}
-
-//static
-ParserCallbackCFuncType Parser::get_callback_validity_warning_cfunc()
-{
-  p_callback_error_or_warning = &callback_error_or_warning;
-  return &c_callback_validity_warning;
-}
-
-//static
-void Parser::callback_error_or_warning(bool is_parser, bool is_error, void* ctx,
-                                       const char* msg, va_list var_args)
 {
   //See xmlHTMLValidityError() in xmllint.c in libxml for more about this:
 
@@ -367,7 +280,7 @@ void Parser::callback_error_or_warning(bool is_parser, bool is_error, void* ctx,
     auto parser = static_cast<Parser*>(context->_private);
     if(parser)
     {
-      auto ubuff = format_xml_error(xmlCtxtGetLastError(context));
+      auto ubuff = format_xml_error(&context->lastError);
       if (ubuff.empty())
       {
         // Usually the result of formatting var_args with the format string msg
@@ -381,19 +294,20 @@ void Parser::callback_error_or_warning(bool is_parser, bool is_error, void* ctx,
 
       try
       {
-        if (is_parser)
+        switch (msg_type)
         {
-          if (is_error)
+          case MsgType::ParserError:
             parser->on_parser_error(ubuff);
-          else
+            break;
+          case MsgType::ParserWarning:
             parser->on_parser_warning(ubuff);
-        }
-        else // validator
-        {
-          if (is_error)
+            break;
+          case MsgType::ValidityError:
             parser->on_validity_error(ubuff);
-          else
+            break;
+          case MsgType::ValidityWarning:
             parser->on_validity_warning(ubuff);
+            break;
         }
       }
       catch (...)
